@@ -3,6 +3,9 @@ from Classification.Instance.Instance import Instance
 
 class KnnInstance(object):
 
+    instance: Instance
+    distance: float
+
     def __init__(self, instance: Instance, distance: float):
         """
         The constructor that sets the instance and distance value.
